@@ -396,7 +396,7 @@ class StatefulAutonomous:
 
         # print out the details of this autonomous mode, and any tunables
 
-        self.battery_voltage = wpilib.DriverStation.getInstance().getBatteryVoltage()
+        self.battery_voltage = wpilib.DriverStation.getBatteryVoltage()
         logger.info("Battery voltage: %.02fv", self.battery_voltage)
 
         logger.info("Tunable values:")
